'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.DomainEvent = exports.DomainEventMessage = void 0;
const cm_libs_utils_1 = require("cm-libs-utils");
const cm_schema_event_1 = require("cm-schema-event");
Object.defineProperty(exports, "DomainEventMessage", { enumerable: true, get: function () { return cm_schema_event_1.DomainEventMessage; } });
const domain_schema_1 = require("./domain-schema");
const domain_event_codec_1 = require("./domain-event-codec");
const domain_event_cipher_1 = require("./domain-event-cipher");
class DomainEvent {
    constructor(schemaName, schema, metadataSchema) {
        this.codec = new domain_event_codec_1.DomainEventCodec();
        this.schema = new domain_schema_1.DomainSchema(schemaName, schema);
        if (metadataSchema) {
            this.metadataSchema = new domain_schema_1.DomainSchema(schemaName, metadataSchema);
        }
    }
    encode({ eventType, eventId, correlationId, correlationTopic, timestamp, body, metadata }) {
        const eventMessage = {
            eventType,
            eventId,
            correlationId,
            correlationTopic,
            timestamp: undefined === timestamp ? (0, cm_libs_utils_1.timeNow)() : timestamp,
            body: this.schema.encode(body),
            metadata: this.metadataSchema ? this.metadataSchema.encode(metadata) : Buffer.alloc(0)
        };
        return this.codec.encode(eventMessage);
    }
    decode(encodedMessage) {
        const { eventType, eventId, correlationId, correlationTopic, timestamp, body, metadata } = this.codec.decode(encodedMessage);
        const message = {
            eventType,
            eventId,
            correlationId,
            correlationTopic,
            timestamp,
            body: this.schema.decode(body),
            metadata: this.metadataSchema ? this.metadataSchema.decode(metadata) : undefined
        };
        return message;
    }
    static init(bdkSet, ksn) {
        domain_event_cipher_1.DomainEventCipher.init(bdkSet, ksn);
    }
}
exports.DomainEvent = DomainEvent;
//# sourceMappingURL=domain-event.js.map