'use strict';
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DomainSchema = void 0;
const avro_js_1 = __importDefault(require("avro-js"));
const cm_libs_context_aware_error_1 = require("cm-libs-context-aware-error");
class DomainSchema {
    constructor(name, contentOrFile) {
        try {
            this.name = name;
            this.schema = avro_js_1.default.parse(contentOrFile);
        }
        catch (error) {
            (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.INVALID_FORMAT, `Invalid AVRO schema: ${name}`, { name, error: error.message });
        }
    }
    encode(value) {
        try {
            return this.schema.toBuffer(value);
        }
        catch (error) {
            (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.INVALID_MESSAGE, `Encode message failed ${this.name}: ${error.message}`, { name: this.name, error: error.message });
        }
    }
    decode(value) {
        try {
            return this.schema.fromBuffer(value);
        }
        catch (error) {
            (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.INVALID_MESSAGE, `Decode message failed ${this.name}: ${error.message}`, { name: this.name, error: error.message });
        }
    }
}
exports.DomainSchema = DomainSchema;
//# sourceMappingURL=domain-schema.js.map